@@ -9,14 +9,18 @@
 #include <fcntl.h>
 #include <linux/kd.h>
 #include <sys/ioctl.h>
-
-extern int getfd(void);
+#include "getfd.h"
+#include "nls.h"
 
 int
 main(int argc, char *argv[]) {
 	struct unimapinit advice;
 	int fd;
 
+	setlocale(LC_ALL, "");
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+
 	fd = getfd();
 
 	advice.advised_hashsize = 0;
@@ -24,7 +28,9 @@ main(int argc, char *argv[]) {
 	advice.advised_hashlevel = 0;
 
 	if(ioctl(fd, PIO_UNIMAPCLR, &advice)) {
-	    perror("PIO_UNIMAPCLR");
-	    exit(1);
+		perror("PIO_UNIMAPCLR");
+		exit(1);
 	}
+
+	return 0;
 }
